@@ -1,18 +1,35 @@
-use anyhow::*;
-use pbkdf2::{Algorithm, Params, Pbkdf2, password_hash::{Ident, Output, PasswordHash, PasswordHasher, PasswordVerifier, Salt, SaltString}};
+pub mod sha256d_digest;
+pub mod hash160_digest;
+pub mod reverse_digest;
+pub mod sha256r_digest;
 
-use bitcoin_hashes::{Hash as BitcoinHash, HashEngine, Hmac, HmacEngine, hash160, hex::ToHex, ripemd160, sha1, sha256, sha256d, sha512};
-use rand_core::OsRng;
+pub use sha256r_digest::*;
+pub use sha256d_digest::*;
+pub use hash160_digest::*;
+pub use reverse_digest::*;
+
+use digest::Digest;
+use hmac::crypto_mac::Key;
+use hmac::{Hmac, Mac, NewMac};
+use anyhow::*;
+use hmac::digest::{BlockInput, FixedOutput, Reset, Update};
+use ripemd160::{Ripemd160};
+use sha1::Sha1;
+use sha2::{Sha256, Sha512};
 use wasm_bindgen::prelude::*;
 use wasm_bindgen::{JsValue, throw_str};
 use serde::*;
+use crate::ToHex;
 use crate::utils::{from_hex, to_hex};
 
+use self::hash160_digest::Hash160;
+use self::sha256d_digest::Sha256d;
+
 
 #[wasm_bindgen]
 #[derive(Debug, Default, Clone, PartialEq, Eq, Serialize, Deserialize)]
-pub struct Hash(
-  #[serde(serialize_with = "to_hex", deserialize_with = "from_hex")]
+pub struct Hash (
+  #[serde(serialize_with = "to_hex", deserialize_with = "from_hex")] 
   pub(crate) Vec<u8>
 );
 
@@ -39,87 +56,90 @@ impl Hash {
 impl Hash {
   #[wasm_bindgen(js_name = sha256d)]
   pub fn sha_256d(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::sha256d::Hash::hash(input).to_vec())
+    Hash((&*Sha256d::digest(input)).to_vec())
   }
 
   #[wasm_bindgen(js_name = sha256)]
   pub fn sha_256(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::sha256::Hash::hash(input).to_vec())
+    Hash((&*Sha256::digest(input)).to_vec())
   }
 
   #[wasm_bindgen(js_name = sha1)]
   pub fn sha_1(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::sha1::Hash::hash(input).to_vec())
+    Hash((&*Sha1::digest(input)).to_vec())
   }
 
   #[wasm_bindgen(js_name = ripemd160)]
   pub fn ripemd_160(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::ripemd160::Hash::hash(input).to_vec())
+    Hash((&*Ripemd160::digest(input)).to_vec())
   }
 
   #[wasm_bindgen(js_name = hash160)]
   pub fn hash_160(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::hash160::Hash::hash(input).to_vec())
+    Hash((&*Hash160::digest(input)).to_vec())
   }
 
   #[wasm_bindgen(js_name = sha512)]
   pub fn sha_512(input: &[u8]) -> Self {
-    Hash(bitcoin_hashes::sha512::Hash::hash(input).to_vec())
+    Hash((&*Sha512::digest(input)).to_vec())
   }
 }
 
-/**
+ /**
   * HMAC Methods
   */
 #[wasm_bindgen]
 impl Hash {
-  fn hmac<T>(input: &[u8], key: &[u8]) -> Hmac<T> where T: BitcoinHash {
-    let mut engine = HmacEngine::<T>::new(key);
-    engine.input(input);
-    let hmac = Hmac::<T>::from_engine(engine);
-
-    hmac
+  
+  // D::BlockSize: ArrayLength<u8>
+  fn hmac<T>(input: &[u8], key: &[u8]) -> Hmac<T> 
+    where T: Update + BlockInput + FixedOutput + Reset + Default + Clone
+  {
+    // Should fix this unwrap, but really shouldnt error.
+    let mut engine = Hmac::<T>::new_from_slice(key).unwrap();
+    engine.update(input);
+    engine
   }
 
   #[wasm_bindgen(js_name = sha512Hmac)]
   pub fn sha_512_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<sha512::Hash>(input, key);
+    let hmac = Hash::hmac::<Sha512>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
 
   #[wasm_bindgen(js_name = sha256Hmac)]
   pub fn sha_256_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<sha256::Hash>(input, key);
+    let hmac = Hash::hmac::<Sha256>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
 
   #[wasm_bindgen(js_name = sha256dHmac)]
   pub fn sha_256d_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<sha256d::Hash>(input, key);
+    let hmac = Hash::hmac::<Sha256d>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
 
   #[wasm_bindgen(js_name = sha1Hmac)]
   pub fn sha_1_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<sha1::Hash>(input, key);
+    let hmac = Hash::hmac::<Sha1>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
 
   #[wasm_bindgen(js_name = ripemd160Hmac)]
   pub fn ripemd_160_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<ripemd160::Hash>(input, key);
+    let hmac = Hash::hmac::<Ripemd160>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
 
   #[wasm_bindgen(js_name = hash160Hmac)]
   pub fn hash_160_hmac(input: &[u8], key: &[u8]) -> Self {
-    let hmac = Hash::hmac::<hash160::Hash>(input, key);
+    let hmac = Hash::hmac::<Hash160>(input, key);
 
-    Self(hmac.as_inner().to_vec())
+    Self(hmac.finalize().into_bytes().to_vec())
   }
-}
+}
\ No newline at end of file
