@@ -2,4 +2,7 @@ mod signature;
 pub use signature::*;
 
 mod errors;
-pub use errors::*;
\ No newline at end of file
+pub use errors::*;
+
+mod sign;
+pub use sign::*;
\ No newline at end of file
