@@ -1,7 +1,9 @@
 mod transaction;
 mod txin;
 mod txout;
+mod sighash;
 
 pub use transaction::*;
 pub use txin::*;
 pub use txout::*;
+pub use sighash::*;
\ No newline at end of file
